@@ -9,6 +9,12 @@ isword  = ascii_letters + digits + '_'
 notword = ''.join((ind 
 for ind in punctuation if ind != '_'))
 
+class CrocsError(Exception):
+    pass
+
+class BadYregex(CrocsError):
+    pass
+
 class BasicRegex:
     def __init__(self, *args):
         self.args  = list(args)
@@ -62,7 +68,9 @@ class BasicRegex:
         stmt = '%s = %s(%s)' % (name, self.__class__.__name__, args)
         lines.append(stmt)
 
-        code = '\n'.join(lines)
+        code = '\n'.join((ind 
+        for ind in lines if ind != ''))
+
         return code
 
     def group_imports(self, argrefs):
@@ -140,9 +148,15 @@ class RegexStr(BasicRegex):
     def hasop(self, instance):
         return False
 
+    def instref(self, argrefs):
+        count = argrefs.setdefault(self.__class__, 0)
+        argrefs[self] = "'%s'" % self.args[0]
+        argrefs[self.__class__] += 1
+        return "'%s'" % self.args[0]
+
     def mkstmts(self, argrefs=dict()):
-        return "%s = %s('%s')" % (self.instref(argrefs), 
-        self.__class__.__name__, self.args[0])
+        self.instref(argrefs)
+        return ''
 
     __str__ = to_regex
 
@@ -185,9 +199,8 @@ class RegexOperator(BasicRegex):
         regex = regexc.search(data)
         assert regex is not None, 'Failed to generate valid matches!'
 
-        print('Input:', data)
+        print('Input:', repr(data))
         print('Regex:', regstr)
-        print('Input:', data)
 
         print('Group dict:', 
         regex.groupdict() if hasattr(
@@ -215,6 +228,9 @@ class RegexOperator(BasicRegex):
         return ''
 
     def hits(self, count=7):
+        """
+        Generate possible matches/hits..
+        """
         data = (self.seed() for ind in range(count))
         print('Match with:\n', ' '.join(data))
 
@@ -229,6 +245,10 @@ class RegexOperator(BasicRegex):
         return regstr
 
     def mkregex(self):
+        """
+        Generate a raw regex.
+        
+        """
         regstr = self.to_regex()
         self.clear()
         return regstr
@@ -236,4 +256,8 @@ class RegexOperator(BasicRegex):
     def __str__(self):
         return self.mkregex()
 
+class RegexMeta(RegexOperator):
+    def mkstmts(self, argrefs):
+        return "%s = %s()" % (self.instref(argrefs), 
+        self.__class__.__name__)
 
