@@ -1,12 +1,9 @@
-from crocs.core import printable, RegexOperator, isword, notword, RegexStr
+from crocs.core import printable, RegexOperator, isword, \
+notword, RegexStr, RegexMeta, BadYregex
 from random import choice, randint
 from itertools import groupby
 
-class Pattern(RegexOperator):
-    """
-    Setup a pattern.
-    """
-
+class JoinX(RegexOperator):
     def __init__(self, *args):
         items = (RegexStr(ind) if isinstance(ind, str) else ind 
         for ind in args)
@@ -16,7 +13,7 @@ class Pattern(RegexOperator):
 
         for indi, indj in opers:
             args.extend(indi.reduce_initargs(*indj))
-        super(Pattern, self).__init__(*args)
+        super(JoinX, self).__init__(*args)
 
     def invalid_data(self):
         return ''.join(map(lambda ind: ind.invalid_data(), self.args))
@@ -24,6 +21,17 @@ class Pattern(RegexOperator):
     def valid_data(self):
         return ''.join(map(lambda ind: ind.valid_data(), self.args))
 
+class Pattern(JoinX):
+    """
+    Setup a pattern.
+    """
+    def __init__(self, *args):
+        for ind in args:
+            if isinstance(ind, Any):
+                raise BadYregex(('Received Any instance!' 
+                    'Wrap it with a group.'))
+        super(Pattern, self).__init__(*args)
+
 class Any(RegexOperator):
     def __init__(self, *args):
         super(Any, self).__init__(*args)
@@ -41,6 +49,27 @@ class Any(RegexOperator):
         data = '|'.join(data)
         return data
 
+class MetaB(RegexMeta):
+    def invalid_data(self):
+        return ''
+
+    def valid_data(self):
+        data = choice(isword) 
+        return  data
+
+    def to_regex(self):
+        return r'\B'
+
+class Metab(RegexMeta):
+    def invalid_data(self):
+        return choice(isword)
+
+    def valid_data(self):
+        return ''
+
+    def to_regex(self):
+        return r'\b'
+
 class Caret(RegexOperator):
     def invalid_data(self):
         return r''
@@ -61,7 +90,7 @@ class Dollar(RegexOperator):
     def to_regex(self):
         return '$' 
 
-class NonCapture(Pattern):
+class NonCapture(JoinX):
     def __init__(self, *args):
         super(NonCapture, self).__init__(*args)
 
@@ -107,7 +136,7 @@ class NotWord(RegexOperator):
         return "%s = %s()" % (self.instref(argrefs), 
         self.__class__.__name__)
 
-class Group(Pattern):
+class Group(JoinX):
     """
     A normal group.
 
@@ -250,17 +279,16 @@ class Repeat(RegexOperator):
 
     MAX = 7
 
-    def __init__(self, regex, min=0, max='', wrap=False, greedy=False):
+    def __init__(self, regex, min=0, max='', greedy=False):
         super(Repeat, self).__init__(regex)
-        self.min = min
-        self.max = max
-        self.wrap = wrap
+        self.min    = min
+        self.max    = max
         self.greedy = greedy
 
         if isinstance(regex, str) and len(regex) > 1:
-            self.args[0] = Group(regex)
-        elif isinstance(regex, Any) and wrap:
-            self.args[0] = Group(regex)
+            raise BadYregex("String length > 1! Use it with a group.")
+        elif isinstance(regex, Any) or isinstance(regex, Pattern):
+            raise BadYregex("Can't repeat! Wrap it with a group.")
 
     def invalid_data(self):
         lim = self.MAX if self.max == '' else self.max
@@ -275,11 +303,11 @@ class Repeat(RegexOperator):
         return ''.join((choice(data) for ind in range(count)))
 
     def valid_data(self):
-        lim = self.MAX if self.max == '' else self.max
+        lim = (self.MAX + self.min) if self.max == '' else self.max
         count = randint(self.min, lim)
 
         data = (self.args[0].valid_data() 
-            for ind in range(count))
+            for ind in range(0, count))
         data = ''.join(data)
 
         return data 
@@ -294,33 +322,33 @@ class Repeat(RegexOperator):
         name = self.instref(argrefs)
 
         code = self.args[0].mkstmts(argrefs)
-        stmt = "%s = %s(%s, min=%s, max=%s, wrap=%s, greedy=%s)"
+        stmt = "%s = %s(%s, min=%s, max=%s, greedy=%s)"
 
         stmt = stmt % (name, 
         self.__class__.__name__, argrefs[self.args[0]], self.min, 
-        self.max if self.max else "''", self.wrap, self.greedy)
+        self.max if self.max != '' else "''", self.greedy)
 
         return '%s\n%s' % (code, stmt)
 
 class ZeroOrMore(Repeat):
-    def __init__(self, regex, min=0, max='', wrap=False, greedy=False):
-        super(ZeroOrMore, self).__init__(regex, 0, wrap=wrap, greedy=greedy)
+    def __init__(self, regex, min=0, max='', greedy=False):
+        super(ZeroOrMore, self).__init__(regex, 0, greedy=greedy)
 
     def to_regex(self):
         return '%s*%s' % (self.args[0].to_regex(), 
         '?' if self.greedy else '')
 
 class OneOrMore(Repeat):
-    def __init__(self, regex, min=1, max='', wrap=False, greedy=False):
-        super(OneOrMore, self).__init__(regex, min, max, wrap=wrap, greedy=greedy)
+    def __init__(self, regex, min=1, max='', greedy=False):
+        super(OneOrMore, self).__init__(regex, min, max, greedy=greedy)
 
     def to_regex(self):
         return '%s+%s' % (self.args[0].to_regex(), 
         '?' if self.greedy else '')
 
 class OneOrZero(Repeat):
-    def __init__(self, regex, min=0, max=1, wrap=False, greedy=False):
-        super(OneOrZero, self).__init__(regex, min, max, wrap=wrap, greedy=greedy)
+    def __init__(self, regex, min=0, max=1, greedy=False):
+        super(OneOrZero, self).__init__(regex, min, max, greedy=greedy)
 
     def to_regex(self):
         return '%s?%s' % (self.args[0].to_regex(), 
@@ -334,6 +362,10 @@ class ConsumeNext(RegexOperator):
     """
 
     def __init__(self, regex0, regex1, neg=False):
+        if isinstance(regex1, Any):
+            raise BadYregex(('Argument regex1 is Any instance!'
+                'Wrap it with a group'))
+
         super(ConsumeNext, self).__init__(regex0, regex1)
         self.neg = neg
 
@@ -384,6 +416,10 @@ class ConsumeBack(ConsumeNext):
     """
 
     def __init__(self, regex0, regex1, neg=False):
+        if isinstance(regex1, Any):
+            raise BadYregex(('Argument regex1 is Any instance!'
+                'Wrap it with a group'))
+
         super(ConsumeBack, self).__init__(regex0, regex1)
         self.neg = neg
 
@@ -433,9 +469,6 @@ class Seq(RegexOperator):
     def to_regex(self):
         return '%s-%s' % (self.start, self.end)
 
-    def clear(self):
-        pass
-
     def mkstmts(self, argrefs):
         return "%s = %s('%s', '%s')" % (self.instref(argrefs), 
         self.__class__.__name__, self.start, self.end)
