@@ -3,8 +3,9 @@ from eacc.lexer import Lexer
 from crocs.grammar import RegexTokens, RegexGrammar, HClassGrammar, HClassTokens
 from crocs.regex import X, Pattern, Group, NonCapture, NamedGroup, Repeat, ZeroOrMore, OneOrMore, \
 OneOrZero, Seq, Include, Exclude, ConsumeNext, ConsumeBack, Any, NGLink, RegexComment, GLink, \
-Word, NotWord, Caret, Dollar
+Word, NotWord, Caret, Dollar, Metab,MetaB
 from crocs.core import BlankX
+import re
 
 class IncludeSet(Eacc):
     def __init__(self):
@@ -56,6 +57,8 @@ class RegexParser(Eacc):
         self.add_handle(RegexGrammar.r_dot, self.dot)
         self.add_handle(RegexGrammar.r_word, self.word)
         self.add_handle(RegexGrammar.r_nword, self.nword)
+        self.add_handle(RegexGrammar.r_metab, self.metab)
+        self.add_handle(RegexGrammar.r_metaB, self.metaB)
 
         self.add_handle(RegexGrammar.r_times0, self.times0)
         self.add_handle(RegexGrammar.r_times1, self.times1)
@@ -97,14 +100,32 @@ class RegexParser(Eacc):
         meta = Word()
         return meta
 
+    def metab(self, escape, wsym):
+        meta = Metab()
+        return meta
+
+    def metaB(self, escape, wsym):
+        meta = MetaB()
+        return meta
+
     def nword(self, escape, wsym):
         meta = NotWord()
         return meta
 
     def pipe(self, regex0, pipe, regex1):
-        data0 = (ind.val() for ind in regex0)
-        data1 = (ind.val() for ind in regex1)
-        pattern0 = Pattern(*data0)
+        data0 = [ind.val() for ind in regex0]
+        data1 = [ind.val() for ind in regex1]
+        pattern0 = None
+        if isinstance(data0[0], Any):
+            pattern0 = data0[0]
+        else:
+            pattern0 = Pattern(*data0)
+
+        pattern1 = Pattern(*data1)
+        pattern2 = Any(pattern0, pattern1)
+        return pattern2
+
+    def reduce_pipe(self, regex0, regex1):
         pattern1 = Pattern(*data1)
         pattern2 = Any(pattern0, pattern1)
         return pattern2
@@ -193,32 +214,43 @@ class RegexParser(Eacc):
         return dollar
 
     def times0(self, regex, lbr, min, comma, max, rbr):
-        e = Repeat(regex.val(), int(min.val()), int(max.val()))
-        return e
+        min = ''.join((ind.val() for ind in min))
+        max = ''.join((ind.val() for ind in max))
+    
+        repeat = Repeat(regex.val(), int(min), int(max))
+        return repeat
 
     def times1(self, regex, lbr, num, rbr):
-        e = Repeat(regex.val(), int(num.val()), int(num.val()))
-        return e
+        num = ''.join((ind.val() for ind in num))
+        num = int(num)
+        repeat = Repeat(regex.val(), num, num)
+        return repeat
 
     def times2(self, regex, lbr, min, comma, rbr):
-        e = Repeat(regex.val(), int(min.val()))
-        return e
+        min = ''.join((ind.val() for ind in min))
+
+        repeat = Repeat(regex.val(), int(min))
+        return repeat
+
+        return repeat
 
     def times3(self, regex, lbr, comma, max, rbr):
-        e = Repeat(regex.val(), max=int(max.val()))
-        return e
+        max = ''.join((ind.val() for ind in max))
+
+        repeat = Repeat(regex.val(), max=int(max))
+        return repeat
 
     def times4(self, regex, mul):
-        e = ZeroOrMore(regex.val())
-        return e
+        repeat = ZeroOrMore(regex.val())
+        return repeat
 
     def times5(self, regex, question):
-        e = OneOrZero(regex.val())
-        return e
+        repeat = OneOrZero(regex.val())
+        return repeat
 
     def times6(self, regex, question):
-        e = OneOrMore(regex.val())
-        return e
+        repeat = OneOrMore(regex.val())
+        return repeat
 
     def times7(self, regex, plus, question):
         """
@@ -265,11 +297,17 @@ class RegexParser(Eacc):
         return RegexComment(comment.val())
 
     def done(self, sof, regex, eof):
-        data = (ind.val() for ind in regex)
-        pattern = Pattern(*data)
-        return pattern
+        data = [ind.val() for ind in regex]
+        if len(data) > 1:
+            return Pattern(*data)
+        return data[0]
 
 def xmake(regstr):
+    """
+    Generate Python code from the regex regstr..
+    """
+    # Make sure the regex is valid before parsing.
+    regexc = re.compile(regstr)
     xlexer  = Lexer(RegexTokens)
     xparser = RegexParser()
 
