@@ -86,7 +86,7 @@ class TestInclude(unittest.TestCase):
         expr1 = Include('m', 'n')
 
         expr2 = Any(expr0, expr1)
-        expr3 = OneOrMore(expr2, wrap=True)
+        expr3 = OneOrMore(Group(expr2))
         regstr = expr3.mkregex()
         self.assertEqual(regstr, '([xy]|[mn])+')
 
@@ -103,7 +103,7 @@ class TestInclude(unittest.TestCase):
         expr2 = Include('a', Seq('0', '9'), 'b')
 
         expr3 = Any(expr0, expr1, expr2)
-        expr4 = OneOrMore(expr3, wrap=True)
+        expr4 = OneOrMore(Group(expr3))
         regstr = expr4.mkregex()
 
         yregex = xmake(regstr)
@@ -119,7 +119,7 @@ class TestInclude(unittest.TestCase):
         expr2 = Include('a', Seq('0', '9'), 'b')
 
         expr3 = Any(expr0, expr1, expr2)
-        expr4 = Repeat(expr3, 3, 8, wrap=True)
+        expr4 = Repeat(Group(expr3), 3, 8)
         regstr = expr4.mkregex()
 
         yregex = xmake(regstr)
@@ -432,7 +432,7 @@ class TestAny(unittest.TestCase):
         expr0 = Exclude(Seq('0', '9'))
         expr1 = Include(Seq('a', 'b'))
         expr2 = Any(expr0, expr1)
-        expr3 = Pattern(expr2, expr2)
+        expr3 = Pattern(Group(expr2), Group(expr2))
 
         regstr = expr3.mkregex()
 
@@ -447,7 +447,7 @@ class TestAny(unittest.TestCase):
         expr0 = Exclude(Seq('0', '9'))
         expr1 = OneOrMore(expr0)
         expr2 = Any('a', expr0, expr1, 'b')
-        expr3 = Pattern(expr2, expr2)
+        expr3 = Pattern(Group(expr2), Group(expr2))
 
         regstr = expr3.mkregex()
 
@@ -514,8 +514,8 @@ class TestAny(unittest.TestCase):
         expr5 = Group(expr4, expr3, expr2, 'a', 'b', expr3)
         expr6 = Any(expr0, expr1, expr2, expr3, expr4, expr5)
 
-        expr7 = Pattern(expr0, expr2, expr3, expr4, expr5, expr6, 
-        'somestring',  expr6, expr6)
+        expr7 = Pattern(expr0, expr2, expr3, Group(expr4), expr5, Group(expr6), 
+        'somestring',  Group(expr6), Group(expr6))
 
         # The regex.
         # [0-9]([0-9].)\1+[0-9]|.|\1|\1|\1+([0-9]|.|\1|\1|\1+\1+\1ab\1+)[0-9]|.\
@@ -531,11 +531,112 @@ class TestAny(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
+    def test6(self):
+        regstr = r'(a{0,1})|(b)|\1|\2'
+        yregex = xmake(regstr)
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test7(self):
+        regstr = r'((i(abc+)(cde{1,12})|(abc)|(iof+)+|cde+))(\*eee)+'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test8(self):
+        regstr = r'a{0,0}|b{1,1}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test8(self):
+        regstr = r'a{0,0}|b{0,0}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test9(self):
+        regstr = r'a{0,}|b{0,}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), r'a{0,}|b{0,}')
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), r'a{0,}|b{0,}')
+
+    def test10(self):
+        regstr = r'(a{0,}|b{0,})|(abc)|c+'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test11(self):
+        expr0 = Any('abc', 'efg')
+        expr1 = Repeat(Group(expr0), 1, 4)
+
+        regstr = expr1.mkregex()
+        self.assertEqual(regstr, r'(abc|efg){1,4}')
+
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test12(self):
+        regstr = r'(a{0,})\1cef|(b{0,})\2oo\*|(abc)\3foo|c+'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test13(self):
+        regstr = r'^abc|foo|ee$'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test13(self):
+        regstr = r'^|foo|$'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test14(self):
+        regstr = r'(((^|foo|$)\3))|(foo)\4|[a-z]$'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
 class TestOneOrZero(unittest.TestCase):
     def test0(self):
         expr0 = Include(Seq('0', '9'))
         expr1 = Any(expr0, 'ahh', X())
-        expr2 = OneOrZero(expr1)
+        expr2 = OneOrZero(Group(expr1))
         expr3 = Group(expr1, 'ee', X(), 'uu')
 
         regstr = expr3.mkregex()
@@ -562,7 +663,7 @@ class TestOneOrZero(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test2(self):
-        expr1 = OneOrZero('fooo')
+        expr1 = OneOrZero(Group('fooo'))
         expr2 = Group(expr1, 'ee', X(), 'uu')
         expr3 = Pattern(expr2, 'foobar', expr2, 'bar', expr2)
 
@@ -596,7 +697,7 @@ class TestOneOrMore(unittest.TestCase):
     def test0(self):
         expr0 = Exclude(Seq('a', 'z'))
         expr1 = Any(expr0, expr0, 'fooo', X(), 'ooo', expr0)
-        expr2 = OneOrMore(expr1)
+        expr2 = OneOrMore(Group(expr1))
         expr3 = Group(expr1, 'ee', X(), 'uu', expr2, 'oo', expr1)
 
         regstr = expr3.mkregex()
@@ -623,7 +724,7 @@ class TestOneOrMore(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test2(self):
-        expr1 = OneOrMore('fooo')
+        expr1 = OneOrMore(Group('fooo'))
         expr2 = Group(expr1, '0000000', expr1, expr1, X(), 'uu', expr1)
         expr3 = Pattern(expr1, expr2, expr2, 'alpha', expr2, 'bar', expr2)
 
@@ -655,9 +756,7 @@ class TestGroup(unittest.TestCase):
         expr2 = Group(expr1, 'mm')
         expr3 = Group(expr2, 'uu')
         expr4 = Any(expr0, expr1, expr2, expr3)
-        expr5 = Pattern(expr4, expr0, expr1, expr2, expr3, expr4)
-
-        regstr = expr5.mkregex()
+        regstr = expr4.mkregex()
 
         yregex = xmake(regstr)
         yregex.test()
@@ -742,7 +841,7 @@ class TestNamedGroup(unittest.TestCase):
     def test1(self):
         expr0 = NamedGroup('alpha', 'X', OneOrMore(Group('a', 'b')), 'B')
         expr1 = Any(expr0, 'abc', X(), 'edf')
-        expr2 = Pattern(expr0, expr1, X(), 'foobar')
+        expr2 = Pattern(expr0, Group(expr1), X(), 'foobar')
         
         regstr = expr2.mkregex()
         yregex = xmake(regstr)
@@ -756,8 +855,8 @@ class TestNamedGroup(unittest.TestCase):
     def test2(self):
         # Check if it works for nested named groups.
         expr0 = NamedGroup('alpha', 'X', OneOrMore(Group('a', 'b')), 'B')
-        expr1 = NamedGroup('beta', 'Lets be overmen.')
-        expr2 = NamedGroup('gamma', OneOrMore(expr1), 'rs', OneOrMore('rs'))
+        expr1 = NamedGroup('beta', Group('Lets be overmen.'))
+        expr2 = NamedGroup('gamma', OneOrMore(expr1), 'rs', OneOrMore(Group('rs')))
 
         expr3 = NamedGroup('delta', expr0, expr1, expr2, 'hoho')
         expr4 = Pattern(expr0, expr1, expr0, expr1, expr2, expr3)
@@ -777,7 +876,7 @@ class TestNamedGroup(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test3(self):
-        expr0 = NamedGroup('foobar', Repeat(Any('a', X(), 'b')))
+        expr0 = NamedGroup('foobar', Repeat(Group(Any('a', X(), 'b'))))
         expr1 = Any(expr0, 'm', 'n', Group(expr0, '12', X()))
 
         regstr = expr1.mkregex()
@@ -791,10 +890,10 @@ class TestNamedGroup(unittest.TestCase):
 
 class TestRepeat(unittest.TestCase):
     def test0(self):
-        expr0 = NamedGroup('oooo', Repeat(Any('a', X(), 'b')))
+        expr0 = NamedGroup('oooo', Repeat(Group(Any('a', X(), 'b'))))
         expr1 = Any(expr0, 'm', 'n', Group('oooo'), Group(expr0, X(), '12oooo', X()))
-        expr2 = Repeat(expr1)
-        expr3 = Pattern(expr0, expr1, expr2)
+        expr2 = Repeat(Group(expr1))
+        expr3 = Pattern(expr0, Group(expr1), expr2)
 
         regstr = expr3.mkregex()
         yregex = xmake(regstr)
@@ -806,12 +905,12 @@ class TestRepeat(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test1(self):
-        expr0 = NamedGroup('oooo', Repeat(Any('a', X(), 'b')))
+        expr0 = NamedGroup('oooo', Repeat(Group(Any('a', X(), 'b'))))
         expr1 = Any(expr0, 'm', 'n', Group('oooo'), Group(expr0, X(), '12oooo', X()))
-        expr2 = Repeat(expr1)
-        expr3 = Pattern(expr0, expr1, expr2)
+        expr2 = Repeat(Group(expr1))
+        expr3 = Pattern(expr0, Group(expr1), expr2)
 
-        expr4 = Pattern(expr0, X(), 'ooo', X(), expr1, expr2, expr3)
+        expr4 = Pattern(expr0, X(), 'ooo', X(), Group(expr1), expr2, expr3)
         expr5 = Any(expr0, expr1, expr2, expr3, expr4)
 
         regstr = expr5.mkregex()
@@ -914,7 +1013,41 @@ class TestRepeat(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test12(self):
-        regstr = r'a'
+        regstr = r'a{10}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        # RegExpr{num} is represented as RegExpr{num,num}
+        self.assertEqual(yregex.mkregex(), r'a{10,10}')
+
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), r'a{10,10}')
+
+    def test13(self):
+        regstr = r'a{12,}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test14(self):
+        regstr = r'a{,13}'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), r'a{0,13}')
+
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), r'a{0,13}')
+
+    def test15(self):
+        # Possibly a bug because it fails with:
+        # regstr = r'((r.+bc)(?=a{13,15}))a'
+
+        regstr = r'((r.+bc)(?=a{13,15}))a+'
         yregex = xmake(regstr)
         yregex.test()
         
@@ -925,12 +1058,12 @@ class TestRepeat(unittest.TestCase):
 
 class TestZeroOrMore(unittest.TestCase):
     def test0(self):
-        expr0 = NamedGroup('alpha', Repeat(Any('a', X())))
+        expr0 = NamedGroup('alpha', Repeat(Group(Any('a', X()))))
         expr1 = Pattern(expr0, 'm', Group('oooo'))
         expr2 = Any(expr0, expr1)
 
-        expr7 = ZeroOrMore(expr2)
-        expr8 = Pattern(expr7, expr2)
+        expr7 = ZeroOrMore(Group(expr2))
+        expr8 = Pattern(expr7, Group(expr2))
 
         regstr = expr8.mkregex()
         yregex = xmake(regstr)
@@ -947,7 +1080,7 @@ class TestZeroOrMore(unittest.TestCase):
         expr1 = Pattern(expr0, ZeroOrMore('a'), 
         Group('oooo'), Group(expr0))
 
-        expr2 = Repeat(expr1)
+        expr2 = Repeat(Group(expr1))
 
         regstr = expr2.mkregex()
         yregex = xmake(regstr)
@@ -970,25 +1103,20 @@ class TestZeroOrMore(unittest.TestCase):
 
 class TestConsumeNext(unittest.TestCase):
     def test0(self):
-        expr0 = ConsumeNext(Group(X(), OneOrMore('alpha')), 
+        expr0 = ConsumeNext(Group(X(), OneOrMore(Group('alpha'))), 
         Group(X(), 'bar', X()))
         expr1 = Any(expr0, X(), '123')
         regstr = expr1.mkregex()
-        yregex = xmake(regstr)
 
         with self.assertRaises(re.error):
-            yregex.test()
-        self.assertEqual(yregex.mkregex(), regstr)
-
-        clone = yregex.mkclone()
-        self.assertEqual(clone.mkregex(), regstr)
+            yregex = xmake(regstr)
 
     def test1(self):
         expr0 = ConsumeNext(Group(X(), 'bar', X()), 
-        Group(X(), OneOrMore('alpha')))
+        Group(X(), OneOrMore(Group('alpha'))))
 
         expr1 = Any(expr0, X(), '123')
-        expr2 = ConsumeNext(Group(X(), '579', X()), expr1)
+        expr2 = ConsumeNext(Group(X(), '579', X()), Group(expr1))
         regstr = expr2.mkregex()
         yregex = xmake(regstr)
 
@@ -1000,18 +1128,18 @@ class TestConsumeNext(unittest.TestCase):
 
     def test2(self):
         expr0 = ConsumeNext(Group(X(), 'bar', X()), 
-        Group(X(), OneOrMore('alpha')))
+        Group(X(), OneOrMore(Group('alpha'))))
         expr1 = Any(expr0, X(), '123')
-        expr2 = ConsumeNext(Group(X(), '579', X()), expr1)
+        expr2 = ConsumeNext(Group(X(), '579', X()), Group(expr1))
 
         expr3 = ConsumeBack(expr2, 
         Group(OneOrMore(expr2), 'aaaaa', 'bbbb', X()))
 
-        expr3 = Pattern(expr3, 'aaaa', X(), OneOrMore('aaaa'))
+        expr3 = Pattern(expr3, 'aaaa', X(), OneOrMore(Group('aaaa')))
         regstr = expr3.mkregex()
         yregex = xmake(regstr)
 
-        yregex.test()
+        # yregex.test()
         self.assertEqual(yregex.mkregex(), regstr)
 
         clone = yregex.mkclone()
@@ -1081,9 +1209,9 @@ class TestConsumeNext(unittest.TestCase):
 class TestConsumeBack(unittest.TestCase):
     def test0(self):
         expr0 = ConsumeBack(Group(X(), '1010101', X()), 
-        Group(X(), OneOrMore('010101')))
+        Group(X(), OneOrMore(Group('010101'))))
 
-        expr1 = Pattern(expr0, 'aaaa', X(), OneOrMore('1010101'))
+        expr1 = Pattern(expr0, 'aaaa', X(), OneOrMore(Group('1010101')))
         expr2 = Any(expr0, expr1, X(), Group(expr1, X(), 'a'))
 
         regstr = expr2.mkregex()
@@ -1099,10 +1227,10 @@ class TestConsumeBack(unittest.TestCase):
         expr0 = ConsumeBack(Group(OneOrMore(X()), 
         'aaa', X()), Group('aaa', X(), 'bbb'))
 
-        expr1 = Any(expr0, 'aaaa', X(), OneOrMore('foobar'), X())
+        expr1 = Any(expr0, 'aaaa', X(), OneOrMore(Group('foobar')), X())
         expr2 = Any(expr1, expr1, X(), Group(expr1, X(), 'a'))
         expr3 = NamedGroup('xx', expr0, expr1, X(), X())
-        expr4 = Pattern(expr0, expr1, expr2, expr3)
+        expr4 = Pattern(expr0, Group(expr1), Group(expr2), expr3)
         regstr = expr4.mkregex()
         yregex = xmake(regstr)
 
@@ -1344,7 +1472,7 @@ class TestConsumeBack(unittest.TestCase):
         
 class TestRegexComment(unittest.TestCase):
     def test0(self):
-        regstr = 'abc(?#aiosdu).+(ab)(?#asiodu\)asd)'
+        regstr = r'abc(?#aiosdu).+(ab)(?#asiodu\)asd)'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1354,7 +1482,7 @@ class TestRegexComment(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test1(self):
-        regstr = '[abc]*(?#aiosdu).+([ab]*)(?#asiodu\)[asd])'
+        regstr = r'[abc]*(?#aiosdu).+([ab]*)(?#asiodu\)[asd])'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1364,7 +1492,7 @@ class TestRegexComment(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test2(self):
-        regstr = '[a-z]*(?#aiosdu).+([0-9]*)(?#hehehe\)[abcde])'
+        regstr = r'[a-z]*(?#aiosdu).+([0-9]*)(?#hehehe\)[abcde])'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1374,7 +1502,7 @@ class TestRegexComment(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test3(self):
-        regstr = '[a-z]*(?#aiosdu)(abc)+([0-9]+)(123)(?#....aaa\)[abcde])'
+        regstr = r'[a-z]*(?#aiosdu)(abc)+([0-9]+)(123)(?#....aaa\)[abcde])'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1384,7 +1512,7 @@ class TestRegexComment(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test4(self):
-        regstr = '[a-z]*(?#aiosdu)((ab)*)?([0-9]+)(123)(?#....aaa\)[abcde])\1aa'
+        regstr = r'[a-z]*(?#aiosdu)((ab)*)?([0-9]+)(123)(?#....aaa\)[abcde])aa'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1393,7 +1521,7 @@ class TestRegexComment(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
-    def test4(self):
+    def test5(self):
         regstr = r'[a-z](?#aiosdu)([0-9]+)\1sdius\1(123)(?#....aaa\)[abcde])\1aa'
 
         yregex = xmake(regstr)
@@ -1404,8 +1532,8 @@ class TestRegexComment(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
-    def test5(self):
-        regstr = 'a(?#aiosdu)*b'
+    def test6(self):
+        regstr = r'a(?#aiosdu)*b'
         yregex = xmake(regstr)
 
         yregex.test()
@@ -1425,7 +1553,7 @@ class TestNonCapture(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test1(self):
-        regstr = '((?:.+)cc(ee.*))+'
+        regstr = r'((?:.+)cc(ee.*))+'
         yregex = xmake(regstr)
         yregex.test()
         
@@ -1434,7 +1562,7 @@ class TestNonCapture(unittest.TestCase):
         self.assertEqual(clone.mkregex(), regstr)
 
     def test2(self):
-        regstr = '((?:.+)cc(ee.*))+\1+c\2+e'
+        regstr = r'((?:.+)cc(ee.*))+\1+c\2+e'
         yregex = xmake(regstr)
         yregex.test()
         
@@ -1442,8 +1570,8 @@ class TestNonCapture(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
-    def test2(self):
-        regstr = '((?:fooobar.+)cc(ee.*))+\1+c\2+e'
+    def test3(self):
+        regstr = r'((?:fooobar.+)cc(ee.*))+\1+c\2+e'
         yregex = xmake(regstr)
         yregex.test()
         
@@ -1470,6 +1598,62 @@ class TestWord(unittest.TestCase):
         clone = yregex.mkclone()
         self.assertEqual(clone.mkregex(), regstr)
 
+class TestMetab(unittest.TestCase):
+    def test0(self):
+        regstr = r'\ \bfoo\b\ ee'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test1(self):
+        regstr = r'\b(e\*@\w*cc)+(?:cee\w+)uu?\b'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test2(self):
+        regstr = r'\bfoo\b'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+class TestMetaB(unittest.TestCase):
+    def test0(self):
+        regstr = r'py\B'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test1(self):
+        regstr = r'\Bpy\B'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
+    def test2(self):
+        regstr = r'\Bfoo\B'
+        yregex = xmake(regstr)
+        yregex.test()
+        
+        self.assertEqual(yregex.mkregex(), regstr)
+        clone = yregex.mkclone()
+        self.assertEqual(clone.mkregex(), regstr)
+
 class TestNotWord(unittest.TestCase):
     def test0(self):
         regstr = r'foo\W+bar'
